#!/bin/bash

VERSION=`python -c "from recent_notifications.Globals import VERSION; print VERSION"`
NAME="recent-notifications-${VERSION}"
SDIST="${NAME}.tar.gz"
ORIG="${NAME}.orig.tar.gz"

# Get command line arguments
BUILD_BINARY=0
CLEAN=0
PRINT_HELP=0

usage () {
  echo "usage: build-package.sh [options]"
  echo ""
  echo "Options:"
  echo "-b, --binary  only build an unsigned binary package"
  echo "-c, --clean   delete everything in the dist directory"
  echo "-h, --help    print this help message and exit"
  echo ""
}

for ARG in $*
do
  case "${ARG}" in
    "-b" | "--binary") BUILD_BINARY=1;;
    "-c" | "--clean" ) CLEAN=1;;
    "-h" | "--help"  ) PRINT_HELP=1;;
  esac
done

# Print the usage and exit
if [ "${PRINT_HELP}" -eq "1" ]
then
  usage
  exit
fi

# Clean the dist directory
if [ "${CLEAN}" -eq "1" ]
then
  echo "Cleaning the dist directory"
  rm -rf dist/*
fi

mkdir -p "dist/deb"

echo "Building source distribution for ${SDIST}"
python setup.py sdist
rm "MANIFEST"
cp "dist/${SDIST}" "dist/deb/${ORIG}"
cd "dist/deb"

echo "Unpacking source distribution in deb directory"
tar xzf "${ORIG}"
cd "${NAME}"

echo "Building deb package"
if [ "${BUILD_BINARY}" -eq "1" ]
then
  dpkg-buildpackage -us -uc
else
  # Build the karmic source package
  dpkg-buildpackage -S
  # Update the changelog for lucid
  #sed -i -e 's/karmic/lucid/g' debian/changelog
  # Build the lucid source package
  #dpkg-buildpackage -S
fi
