"""
Timestamp.py
by Jason Conti
March 15, 2010

Functions for working with timestamps.
"""

import locale

from datetime import datetime

from Translations import _

def now():
  """Returns a datetime objects with the current timestamp."""
  return datetime.now()

def locale_date(timestamp):
  """Returns a string with the date in the current locales format."""
  return timestamp.strftime(locale.nl_langinfo(locale.D_FMT))

def locale_datetime(timestamp):
  """Returns a string with the date and time in the current locales format."""
  return timestamp.strftime(locale.nl_langinfo(locale.D_T_FMT))

def locale_time(timestamp):
  """Returns a string with the time in the current locales format."""
  return timestamp.strftime(locale.nl_langinfo(locale.T_FMT))

def time_ago_in_words(timestamp):
  """Returns a string in a format such as "less than a minute ago" or "2 hours ago"
  the distance in time from timestamp to now. If the difference is more than
  a day, returns locale_datetime instead."""
  delta = now() - timestamp
  s = delta.seconds
  m = s / 60
  h = m / 60
  d = delta.days

  if d < 1:
    if s < 60:
      return _("less than a minute ago")
    elif m == 1:
      return _("1 minute ago")
    elif m < 60:
      return str(m) + _(" minutes ago")
    elif h == 1:
      return _("1 hour ago")
    else:
      return str(h) + _(" hours ago")

  else:
    return locale_datetime(timestamp)

